Package 'tuRkey'

Title: Prepare the time needed to cook a turkey of a given weight
Description: This was a christmas hoje to learn how long a Turkey need to be in the oven
Authors: person("Eduardo", "Hellas", email = "[email protected]", role = c("aut", "cre"))
Maintainer: Eduardo Hellas <[email protected]>
License: MIT + file LICENSE
Version: 0.1.0
Built: 2026-06-17 18:34:31 UTC
Source: https://github.com/pinduzera/turkey

Help Index


Return timer in minutes to cook time of a turkey of a given size

Description

Return timer in minutes to cook time of a turkey of a given size

Usage

cook_turkey(pounds)

Arguments

pounds

Turkey weight in pounds.

Value

The sum of x and y.

Examples

cook_turkey(10)